@@ -1,6 +1,65 @@
+package Yars;
+
+use strict;
+use warnings;
+use Mojo::Base 'Clustericious::App';
+use Yars::Routes;
+use Yars::Tools;
+use Mojo::ByteStream qw/b/;
+use File::Path qw/mkpath/;
+
+# ABSTRACT: Yet Another RESTful-Archive Service
+our $VERSION = '0.78'; # VERSION
+
+
+has secret => rand;
+
+
+sub startup {
+    my $self = shift;
+    if ($Mojolicious::VERSION >= 2.37) {
+        Mojo::IOLoop::Stream->timeout(3000);
+    } else {
+        Mojo::IOLoop->singleton->connection_timeout(3000);
+    }
+    $self->hook(
+        after_build_tx => sub {
+            my ( $tx, $app ) = @_;
+            $tx->req->content->on(body => sub {
+                    my $content = shift;
+                    my $md5_b64 = $content->headers->header('Content-MD5') or return;
+                    my $md5 = unpack 'H*', b($md5_b64)->b64_decode;
+                    my $disk = Yars::Tools->disk_for($md5) or return;
+                    my $tmpdir = join '/', $disk, 'tmp';
+                    -d $tmpdir or do { mkpath $tmpdir;  chmod 0777, $tmpdir; };
+                    -w $tmpdir or chmod 0777, $tmpdir;
+                    $content->asset->on(
+                        upgrade => sub {
+                            my ( $mem, $file ) = @_;
+                            $file->tmpdir($tmpdir);
+                        }
+                    );
+                }
+            );
+        }
+    );
+    $self->SUPER::startup(@_);
+}
+
+
+1;
+
+__END__
+
+=pod
+
 =head1 NAME
 
-Yars -- Yet Another RESTful-Archive Service
+Yars - Yet Another RESTful-Archive Service
+
+=head1 VERSION
+
+version 0.78
 
 =head1 DESCRIPTION
 
@@ -148,71 +207,33 @@ L<Yars> is the application package, it inherits from
 L<Clustericious::App> and overrides the following
 methods :
 
-=cut
-
-package Yars;
-
-use strict;
-use warnings;
-use Mojo::Base 'Clustericious::App';
-use Yars::Routes;
-use Yars::Tools;
-use Mojo::ByteStream qw/b/;
-use File::Path qw/mkpath/;
-our $VERSION = '0.77';
-
-has secret => rand;
-
 =head2 startup
 
 Called by the server to start up, we change
 the object classes to use Yars::Message::Request
 for incoming requests.
 
-=cut
-
-sub startup {
-    my $self = shift;
-    if ($Mojolicious::VERSION >= 2.37) {
-        Mojo::IOLoop::Stream->timeout(3000);
-    } else {
-        Mojo::IOLoop->singleton->connection_timeout(3000);
-    }
-    $self->hook(
-        after_build_tx => sub {
-            my ( $tx, $app ) = @_;
-            $tx->req->content->on(body => sub {
-                    my $content = shift;
-                    my $md5_b64 = $content->headers->header('Content-MD5') or return;
-                    my $md5 = unpack 'H*', b($md5_b64)->b64_decode;
-                    my $disk = Yars::Tools->disk_for($md5) or return;
-                    my $tmpdir = join '/', $disk, 'tmp';
-                    -d $tmpdir or do { mkpath $tmpdir;  chmod 0777, $tmpdir; };
-                    -w $tmpdir or chmod 0777, $tmpdir;
-                    $content->asset->on(
-                        upgrade => sub {
-                            my ( $mem, $file ) = @_;
-                            $file->tmpdir($tmpdir);
-                        }
-                    );
-                }
-            );
-        }
-    );
-    $self->SUPER::startup(@_);
-}
-
 =head1 AUTHORS
 
- Marty Brandon
+Current maintainer: Graham Ollis <plicease@cpan.org>
 
- Brian Duggan
+Previous maintainer: Marty Brandon
+
+Original author: Brian Duggan
 
 =head1 SEE ALSO
 
 L<Yars::Client>
 
+=head1 AUTHOR
+
+Graham Ollis <plicease@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by NASA GSFC.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-
-1;
